@@ -1,2 +1,2 @@
 from .ext.commands import *
-from .Bot import Bot
+from .Bot import BaseBot
