@@ -1,14 +1,16 @@
-from async_vk_bots.Bot import Bot
 from .Context import Context
-from .Scenario import Scenario
+from .Scenario import Scenario, create_handler
 
 
-def command(regexp):
-    def decorator(func):
-        if Bot.bot:
-            Bot.bot.add_command(regexp, func)
-        return func
-    return decorator
+def create_command(commands):
+    def command(regexp):
+        def decorator(func):
+            if regexp not in commands:
+                commands[regexp] = list()
+            commands[regexp].append(func)
+            return func
+        return decorator
+    return command
 
 
 def need_ability(abilities_list):
